operator
==========

.. toctree::
   :maxdepth: 4

.. autoclass:: nngen.operator.basic.add
   :members: 
      
.. autoclass:: nngen.operator.basic.sub
   :members: 

.. autoclass:: nngen.operator.basic.add_n
   :members: 
      
.. autoclass:: nngen.operator.basic.lshift
   :members: 
      
.. autoclass:: nngen.operator.basic.rshift
   :members: 
      
.. autoclass:: nngen.operator.basic.rshift_round
   :members: 
      
.. autoclass:: nngen.operator.basic.multiply
   :members: 
      
.. autoclass:: nngen.operator.basic.reduce_sum
   :members: 
      
.. autofunction:: nngen.operator.basic.reshape
      
.. autofunction:: nngen.operator.basic.expand_dims
      
.. autoclass:: nngen.operator.basic.transpose
      
.. autoclass:: nngen.operator.relu.relu
   :members: 
      
.. autoclass:: nngen.operator.relu.relu6
   :members: 
      
.. autoclass:: nngen.operator.conv2d.conv2d
   :members:

